@@ -18,7 +18,7 @@ if TYPE_CHECKING:
 
 class SimpleGlyph:
     ''' Simple Glyph '''
-    dfltsize = 12   # Draw <symbols> in this point size
+    DFLT_SIZE_PT = 12   # Draw <symbols> in this point size
 
     def __init__(self, index: int, operators: Sequence[SVGOpType],
                  bbox: BBox, font: Font):
@@ -31,7 +31,7 @@ class SimpleGlyph:
         basename, _ = os.path.splitext(os.path.basename(self.font.info.filename))
         basename = ''.join(c for c in basename if c.isalnum())
         self.id = f'{basename}_{index}'
-        self.emscale = self.dfltsize / self.font.info.layout.unitsperem
+        self._points_per_unit = self.DFLT_SIZE_PT / self.font.info.layout.unitsperem
 
     def _repr_svg_(self):
         return ET.tostring(self.svgxml(), encoding='unicode')
@@ -42,33 +42,38 @@ class SimpleGlyph:
         if self.font.cmap:
             return self.font.cmap.char(self.index)
         return set()
-    
-    def place(self, x: float, y: float, fontsize: float) -> Optional[ET.Element]:
+
+    def funits_to_points(self, value: float, scale_factor: float = 1) -> float:
+        ''' Convert font units to points '''
+        return value * self._points_per_unit * scale_factor
+
+    def place(self, x: float, y: float, point_size: float) -> Optional[ET.Element]:
         ''' Get <use> svg tag translated/scaled to the right position '''
-        fntscale = (fontsize/self.dfltsize)
-        yshift = self.font.info.layout.ymax * self.emscale * fntscale
+        scale_factor = point_size / self.DFLT_SIZE_PT
+        yshift = self.funits_to_points(
+            max(self.bbox.ymax, self.font.info.layout.ymax), scale_factor)
         elm: Optional[ET.Element]
         if config.svg2:
             elm = ET.Element('use')
             elm.attrib['href'] = f'#{self.id}'
-            dx = min(self.bbox.xmin * self.emscale * fntscale, 0)
-            elm.attrib['transform'] = f'translate({fmt(x+dx)} {fmt(y-yshift)}) scale({fmt(fntscale)})'
+            dx = min(self.funits_to_points(self.bbox.xmin, scale_factor), 0)
+            elm.attrib['transform'] = (f'translate({fmt(x+dx)} '
+                                       f'{fmt(y-yshift)}) scale({fmt(scale_factor)})')
         else:
-            elm = self.svgpath(x0=x, y0=y, scale=fntscale)
+            elm = self.svgpath(x0=x, y0=y, scale_factor=scale_factor)
         return elm
 
-    def advance(self, nextchr=None):
+    def advance(self, nextchr=None) -> float:
         ''' Get advance width in glyph units, including kerning if nextchr is defined '''
         if nextchr:
             nextchr = nextchr.index
         return self.font.advance(self.index, nextchr)
 
-    def svgpath(self, x0: float = 0, y0: float = 0, scale: float = 1) -> Optional[ET.Element]:
+    def svgpath(self, x0: float = 0, y0: float = 0, scale_factor: float = 1) -> Optional[ET.Element]:
         ''' Get svg <path> element for glyph, normalized to 12-point font '''
-        emscale = self.emscale * scale
         path = ''
-        for i, op in enumerate(self.operators):
-            segment = op.path(x0, y0, scale=emscale)
+        for operator in self.operators:
+            segment = operator.path(x0, y0, scale=self.funits_to_points(1, scale_factor))
             if segment[0] == 'M' and path != '':
                 path += 'Z '  # Close intermediate segments
             path += segment
@@ -79,11 +84,11 @@ class SimpleGlyph:
 
     def svgsymbol(self) -> ET.Element:
         ''' Get svg <symbol> element for this glyph, scaled to 12-point font '''
-        xmin = min(self.bbox.xmin * self.emscale, 0)
-        xmax = self.bbox.xmax * self.emscale
+        xmin = min(self.funits_to_points(self.bbox.xmin), 0)
+        xmax = self.funits_to_points(self.bbox.xmax)
         width = xmax-xmin
-        ymax = max(self.font.info.layout.ymax, self.bbox.ymax) * self.emscale
-        ymin = min(self.font.info.layout.ymin, self.bbox.ymin) * self.emscale
+        ymax = self.funits_to_points(max(self.font.info.layout.ymax, self.bbox.ymax))
+        ymin = self.funits_to_points(min(self.font.info.layout.ymin, self.bbox.ymin))
         height = ymax - ymin
 
         sym = ET.Element('symbol')
@@ -91,32 +96,30 @@ class SimpleGlyph:
         sym.attrib['width'] = fmt(width)
         sym.attrib['height'] = fmt(height)
         sym.attrib['viewBox'] = f'{fmt(xmin)} {fmt(-ymax)} {fmt(width)} {fmt(height)}'
-        path = self.svgpath()
-        if path is not None:
+        if (path := self.svgpath()) is not None:
             sym.append(path)
         return sym
 
-    def svg(self, fontsize: float = None) -> str:
+    def svg(self, point_size: Optional[float] = None) -> str:
         ''' Get SVG as string '''
-        return ET.tostring(self.svgxml(fontsize), encoding='unicode')
+        return ET.tostring(self.svgxml(point_size), encoding='unicode')
 
-    def svgxml(self, fontsize: float = None) -> ET.Element:
+    def svgxml(self, point_size: Optional[float] = None) -> ET.Element:
         ''' Standalong SVG '''
-        fontsize = fontsize if fontsize else config.fontsize
-        scale = fontsize / self.font.info.layout.unitsperem
+        point_size = point_size if point_size else config.fontsize
+        scale_factor = point_size / self.DFLT_SIZE_PT
 
         # Width varies by character, but height is constant for the whole font
         # View should include whole character, even if it goes negative/outside the advwidth
-        xmin = min(self.bbox.xmin * scale, 0)
-        xmax = self.bbox.xmax * scale
-        ymin = min(self.bbox.ymin, self.font.info.layout.ymin) * scale
+        xmin = self.funits_to_points(min(self.bbox.xmin, 0), scale_factor)
+        xmax = self.funits_to_points(self.bbox.xmax, scale_factor)
+        ymin = self.funits_to_points(min(self.bbox.ymin, self.font.info.layout.ymin), scale_factor)
 
         # ymax can go above font's ymax for extended (ie math) glyphs
-        ymax = max(self.bbox.ymax, self.font.info.layout.ymax) * scale
+        ymax = self.funits_to_points(max(self.bbox.ymax, self.font.info.layout.ymax), scale_factor)
         width = xmax - xmin
         height = ymax - ymin
         base = ymax
-        scale = fontsize/self.dfltsize
 
         svg = ET.Element('svg')
         svg.attrib['width'] = fmt(width)
@@ -125,7 +128,7 @@ class SimpleGlyph:
         svg.attrib['viewBox'] = f'{fmt(xmin)} 0 {fmt(width)} {fmt(height)}'
         if not config.svg2:
             svg.attrib['xmlns:xlink'] = 'http://www.w3.org/1999/xlink'
-            elm = self.svgpath(x0=0, y0=base, scale=scale)
+            elm = self.svgpath(x0=0, y0=base, scale_factor=scale_factor)
             if elm is not None:
                 svg.append(elm)
         else:
@@ -133,10 +136,11 @@ class SimpleGlyph:
             svg.append(symbol)
             g = ET.SubElement(svg, 'use')
             g.attrib['href'] = f'#{self.id}'
-            g.attrib['transform'] = f'translate({fmt(xmin)}, {fmt(base-ymax)}) scale({fmt(scale)})'
+            g.attrib['transform'] = (f'translate({fmt(xmin)}, '
+                                     f'{fmt(base-ymax)}) scale({fmt(scale_factor)})')
         return svg
 
-    def test(self, pxwidth: float=400, pxheight: float=400) -> InspectGlyph:
+    def test(self, pxwidth: float = 400, pxheight: float = 400) -> InspectGlyph:
         ''' Get Glyph Test representation showing vertices and borders '''
         return InspectGlyph(self, pxwidth, pxheight)
 
@@ -164,13 +168,12 @@ class CompoundGlyph(SimpleGlyph):
             n0 = max(abs(xform.c), abs(xform.d))
             m = 2*m0 if abs(abs(xform.a)-abs(xform.c)) <= 33/65536 else m0
             n = 2*n0 if abs(abs(xform.b)-abs(xform.d)) <= 33/65536 else n0
-            for op in glyph.operators:
-                xoperators.append(op.xform(xform.a, xform.b, xform.c,
-                                           xform.d, xform.e, xform.f, m, n))
+            for operator in glyph.operators:
+                xoperators.append(operator.xform(xform.a, xform.b, xform.c,
+                                                 xform.d, xform.e, xform.f, m, n))
         return xoperators
 
 
-
 class EmptyGlyph(SimpleGlyph):
     ''' Glyph with no contours (like a space) '''
     def __init__(self, index: int, font: Font):
